@@ -87,7 +87,28 @@ class ToolInflux:
         """Funcion encargada de cerrar la conexion instanciada"""
         self.client.close()
 
-    def set_query(
+    def datetime_to_timestamp_grafana(self, datetime_obj: datetime) -> int:
+        """Deuelve el valor de un datetime en formato timestamp
+        valido para poder realizar consultas en InfluxDB
+
+        :param datetime_obj: Fecha que se quiere pasar a timestamp
+        :type datetime_obj: datetime
+        :return: Valor timestamp para introducir en una query InfluxDB
+        :rtype: int
+        """
+        if isinstance(datetime_obj, str):
+            time_parse_or_dt = parse(datetime_obj)
+        else:
+            time_parse_or_dt = datetime_obj
+        timestamp_wf = str(time_parse_or_dt.timestamp()).split(".")
+        # en el caso de que el timestamp[1] tenga menos de tres numeros
+        # le añado 0 para que asi el timestamp final tenga una longitud
+        # estrcita de 13
+        if len(timestamp_wf[1][:3]) < 3:
+            timestamp_wf[1] = timestamp_wf[1][:3] + "0" * (3 - len(timestamp_wf[1][:3]))
+        return int(timestamp_wf[0] + timestamp_wf[1][:3])
+
+    def select_query(
         self,
         table: str,
         col: str = "*",
@@ -114,19 +135,6 @@ class ToolInflux:
         :rtype: str
         """
 
-        # funcion que pasa de str/datetime a timestamp
-        # con el formato estrcito de grafana para la
-        # query
-        def datetime_to_timestamp_grafana(datetime_obj):
-            if isinstance(datetime_obj, str):
-                time_parse_or_dt = parse(datetime_obj)
-            else:
-                time_parse_or_dt = datetime_obj
-            timestamp_wf = str(time_parse_or_dt.timestamp()).split(".")
-            if len(timestamp_wf[1][:3]) < 3:
-                timestamp_wf[1] = timestamp_wf[1][:3] + '0'*(3-len(timestamp_wf[1][:3]))
-            return int(timestamp_wf[0] + timestamp_wf[1][:3])
-
         # En esta version, o solo puede haber selector o aggregation
         if isinstance(selector, str) and isinstance(aggregation, type(None)):
             if col == "*":
@@ -145,7 +153,7 @@ class ToolInflux:
         # en el caso de que no haya ningun selector o aggregation o hayan ambas
         # lo cual en esta version no esta permitido, comenta que se elimina ambas
         # operaciones y aplica simplemente SELECT *
-        else: # falta especificar y si no son None para que entre aqui!!
+        else:  # falta especificar y si no son None para que entre aqui!!
             if isinstance(aggregation, str) and isinstance(selector, str):
                 print(
                     "En esta version solo se puede tener o un selector o una agregacion\n \
@@ -161,15 +169,15 @@ class ToolInflux:
             time_q = " "
 
         elif not isinstance(time, tuple):
-            time_start = datetime_to_timestamp_grafana(time)
+            time_start = self.datetime_to_timestamp_grafana(time)
             # si solo hay una fecha se supone que estoy diciendo desde donde
             # quiero los datos y que me coja hasta el momento actual, now()
             time_q = f" WHERE time >= {time_start}ms and time <= now() "
         # en el caso de que si haya una tupla con dos valores, se supone
         # que estoy especificando un rango de fechas
         else:
-            time_0 = datetime_to_timestamp_grafana(time[0])
-            time_1 = datetime_to_timestamp_grafana(time[1])
+            time_0 = self.datetime_to_timestamp_grafana(time[0])
+            time_1 = self.datetime_to_timestamp_grafana(time[1])
             # verifico que el rango de fechas se paso primero
             # la fecha mas antigua y luego la fecha mas reciente
             if time_0 < time_1:
@@ -287,18 +295,3 @@ class ToolInflux:
 
         # y ahora registro los datos
         self.client.write_points(dataframe, table)
-
-# if __name__ == "__main__":
-#     from datetime import timedelta
-
-#     rasp_pvpc = ToolInflux(database="pvpc", ip_address = "10.141.188.140")
-#     local_pvpc = ToolInflux(database="pvpc")
-
-#     client_rasp = rasp_pvpc.get_client()
-#     client_local = local_pvpc.get_client()
-
-#     last_registry_local = local_pvpc.get_last_index(table="data_pvpc") - timedelta(days=5)
-#     # last_registry_local = last_registry_local - timedelta(days=5)
-
-#     query = rasp_pvpc.set_query(table="data_pvpc", time=last_registry_local)
-#     df_rasp_pvpc = rasp_pvpc.get_table(query=query, table="data_pvpc", return_dataframe=True)
\ No newline at end of file
